Module url_string

Module url_string 

Convert bytes to the string which can be used as a part of URL and vice versa

Modules

b8s_and_b6s
char_and_b6

Functions

get_bytes
Convert the string which consists of A-Za-z0-9, hyphen and underscore to bytes.
get_url_string
Convert bytes to the string which consists of A-Za-z0-9, hyphen and underscore