Convert bytes to the string which can be used as a part of URL and vice versa
Modules
Functions
- get_
bytes - Convert the string which consists of A-Za-z0-9, hyphen and underscore to bytes.
- get_
url_ string - Convert bytes to the string which consists of A-Za-z0-9, hyphen and underscore